@@ -39,7 +39,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
 
     // let the dialog look nice
     setCaption( i18n("Add CD tracks") );
-    setIcon( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small) );
+    setIcon( iconLoader->loadIcon("media-optical-cdaudio-unmounted",TDEIcon::Small) );
 
     // the grid for all widgets in the dialog
     TQGridLayout* gridLayout = new TQGridLayout( this, 1, 1, 11, 6, "gridLayout" );
@@ -76,7 +76,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
              );
     //artistBox->addStretch();
     artistBox->addSpacing( 130 );
-//     pCDDB = new KPushButton( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small), i18n("Request CDDB"), this, "pCDDB" );
+//     pCDDB = new KPushButton( iconLoader->loadIcon("media-optical-cdaudio-unmounted",TDEIcon::Small), i18n("Request CDDB"), this, "pCDDB" );
 //     topGridLayout->addWidget( pCDDB, 0, 8 );
 
     // set up the second row at the top
@@ -250,7 +250,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     cAdd->insertItem( iconLoader->loadIcon("document-open",TDEIcon::Small),i18n("Add all tracks") );
     cAdd->insertItem( iconLoader->loadIcon("document-open",TDEIcon::Small),i18n("Add selected tracks") );
     RipperPlugin* plugin = config->getCurrentRipper();
-    if( plugin != 0 && plugin->rip.full_disc.enabled ) cAdd->insertItem( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small),i18n("Add full CD as one file") );
+    if( plugin != 0 && plugin->rip.full_disc.enabled ) cAdd->insertItem( iconLoader->loadIcon("media-optical-cdaudio-unmounted",TDEIcon::Small),i18n("Add full CD as one file") );
     //cAdd->setSizeMode( ComboButton::Min );
     controlBox->addWidget( cAdd );
     connect( cAdd, TQT_SIGNAL(clicked(int)),
