@@ -14,7 +14,7 @@
 #include <tqcheckbox.h>
 
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kscrollview.h>
 #include <kstandarddirs.h>
@@ -38,7 +38,7 @@ ConfigBackendsPage::ConfigBackendsPage( Config* _config, TQMap<TQString, TQStrin
     TQHBox* legendBox = new TQHBox( box );
     legendBox->setMargin( 0 );
     legendBox->setSpacing( 6 );
-    KStandardDirs* stdDirs = new KStandardDirs();
+    TDEStandardDirs* stdDirs = new TDEStandardDirs();
     TQLabel* lLegendLabel = new TQLabel( i18n("Legend")+":", legendBox, "lLegendLabel" );
     TQLabel* lLegendGreen = new TQLabel( "", legendBox, "lLegendGreen" );
     lLegendGreen->setPixmap( TQPixmap(stdDirs->findResource("data","soundkonverter/pics/ledgreen_legend.png")) );
@@ -329,12 +329,12 @@ void ConfigBackendsPage::rebuild()
 
 void ConfigBackendsPage::refill()
 {
-    KStandardDirs* stdDirs = new KStandardDirs();
+    TDEStandardDirs* stdDirs = new TDEStandardDirs();
     int i, item;
 
     cRipper->clear();
     i = item = 0;
-    cRipper->insertItem( TQPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), i18n("KDE audio CD protocol") );
+    cRipper->insertItem( TQPixmap(stdDirs->findResource("data","soundkonverter/pics/ledyellow.png")), i18n("TDE audio CD protocol") );
     i++;
     TQValueList<RipperPlugin*> rippers = config->allRippers();
     for( TQValueList<RipperPlugin*>::Iterator it = rippers.begin(); it != rippers.end(); ++it )
