@@ -9,11 +9,11 @@
 #include <tqstring.h>
 #include <tqtooltip.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <ktoolbarbutton.h>
+#include <tdemessagebox.h>
+#include <tdetoolbarbutton.h>
 //#include <kdebug.h>
 #include <kpushbutton.h>
 
@@ -28,7 +28,7 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
     optionsDetailed = _optionsDetailed;
 
     // create an icon loader object for loading icons
-    KIconLoader* iconLoader = new KIconLoader();
+    TDEIconLoader* iconLoader = new TDEIconLoader();
 
     TQGridLayout *grid = new TQGridLayout( this, 3, 1, 6, 3 );
 
@@ -58,16 +58,16 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
                this, TQT_SLOT(somethingChanged())
              );
     topBox->addSpacing( 3 );
-    //pProfileRemove = new KToolBarButton( "editdelete", 1002, this, "pProfileRemove" );
-    pProfileRemove = new KPushButton( iconLoader->loadIcon("editdelete",KIcon::Small), i18n("Remove"), this, "pProfileRemove" );
+    //pProfileRemove = new TDEToolBarButton( "edit-delete", 1002, this, "pProfileRemove" );
+    pProfileRemove = new KPushButton( iconLoader->loadIcon("edit-delete",TDEIcon::Small), i18n("Remove"), this, "pProfileRemove" );
     pProfileRemove->hide();
     TQToolTip::add( pProfileRemove, i18n("Remove the selected profile") );
     topBox->addWidget( pProfileRemove, 0, TQt::AlignVCenter );
     connect( pProfileRemove, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(profileRemove())
              );
-    //pProfileInfo = new KToolBarButton( "messagebox_info", 1110, this, "pProfileInfo" );
-    pProfileInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",KIcon::Small), i18n("Info"), this, "pProfileInfo" );
+    //pProfileInfo = new TDEToolBarButton( "messagebox_info", 1110, this, "pProfileInfo" );
+    pProfileInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",TDEIcon::Small), i18n("Info"), this, "pProfileInfo" );
     TQToolTip::add( pProfileInfo, i18n("Information about the selected profile") );
     topBox->addWidget( pProfileInfo, 0, TQt::AlignVCenter );
     connect( pProfileInfo, TQT_SIGNAL(clicked()),
@@ -86,8 +86,8 @@ OptionsSimple::OptionsSimple( Config* _config, OptionsDetailed* _optionsDetailed
                this, TQT_SLOT(somethingChanged())
              );
     topBox->addSpacing( 3 );
-    //pFormatInfo = new KToolBarButton( "messagebox_info", 1111, this, "pFormatInfo" );
-    pFormatInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",KIcon::Small), i18n("Info"), this, "pFormatInfo" );
+    //pFormatInfo = new TDEToolBarButton( "messagebox_info", 1111, this, "pFormatInfo" );
+    pFormatInfo = new KPushButton( iconLoader->loadIcon("messagebox_info",TDEIcon::Small), i18n("Info"), this, "pFormatInfo" );
     TQToolTip::add( pFormatInfo, i18n("Information about the selected file format") );
     topBox->addWidget( pFormatInfo, 0, TQt::AlignVCenter );
     connect( pFormatInfo, TQT_SIGNAL(clicked()),
