@@ -8,7 +8,7 @@
 
 class Config;
 class Logger;
-class KProcess;
+class TDEProcess;
 
 /**
  * @short Starts a process to add/remove Replay Gain tags to/from a given file
@@ -18,7 +18,7 @@ class KProcess;
 class ReplayGain : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     enum Mode {
         calc_track        = 0x0001,
@@ -41,10 +41,10 @@ public:
      * Add/remove Replay Gain
      * @param files a list of files (of the same format)
      * @param format the format of the file/files (extension or mime type)
-     * @param prc a pointer to a KProcess
+     * @param prc a pointer to a TDEProcess
      * @param remove if true the Replay Gain tags are being removed, if false (default) the tags are calculated and added
      */
-    bool apply( TQStringList files, const TQString& format, KProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const TQStringList& ?
+    bool apply( TQStringList files, const TQString& format, TDEProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const TQStringList& ?
 
     /*
      * Returns the track and the album gain (in this order) of the @p file
